library imepay_merchant_sdk;

import 'dart:convert';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import '/country_picker/country_picker_dialog.dart';
import '/model/request_model.dart';
import '/start_sdk.dart';
import '/views/loadin_overlay.dart';
import '/webservice/web_service.dart';
import 'constants/app_constants.dart';
import 'country_picker/country.dart';
import 'country_picker/country_picker_dropdown.dart';
import 'model/payment_response_model.dart';
import 'utils/utils.dart';
import 'views/review_screen.dart';
import 'widget/custom_text_input_field.dart';

class PhoneNumberScreen extends StatefulWidget {
  RequestModel requestModel;

  PhoneNumberScreen(this.requestModel);

  @override
  _PhoneNumberScreenState createState() => _PhoneNumberScreenState();
}

class _PhoneNumberScreenState extends State<PhoneNumberScreen> {
  TextEditingController _countryCodeControler = TextEditingController();
  TextEditingController phoneNumberController = TextEditingController();
  Country _selectedDialogCountry =
      CountryPickerUtils.getCountryByPhoneCode('977');
  int textLength = 10;
  bool isFloatingActive = false;
  bool isLoading = false;
  String countryCode = "";
  final GlobalKey<ScaffoldState> _scaffoldKey = new GlobalKey<ScaffoldState>();

  @override
  void initState() {
    _countryCodeControler.text = "+977";
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return GetMaterialApp(
        debugShowCheckedModeBanner: false,
        home: LoadingOverlay(
          isLoading: isLoading,
          progressIndicator: CircularProgressIndicator(color: Colors.red,),
          color: Colors.black.withOpacity(0.5),
          child: Scaffold(
              key: _scaffoldKey,
              backgroundColor: Colors.white,
              floatingActionButton: FloatingActionButton(
                elevation: 0,
                onPressed: () async {
                  if (isFloatingActive) {
                    onSubmitClicked();
                  }
                },
                enableFeedback: true,
                child: const Icon(Icons.arrow_forward),
                backgroundColor:
                    isFloatingActive ? Colors.red : Colors.red.shade200,
              ),
              appBar: AppBar(
                backgroundColor: Colors.white,
                toolbarHeight: 56,
                elevation: 0,
                leading: InkWell(
                    onTap: () {
                      StartSdk.setResult(
                        context,
                        PaymentResponseModel(
                            responseDescription:
                                "Transaction cancel by user. RefId= ${widget.requestModel.refId.toString()}",
                            responseCode: -1),
                      );

                      Navigator.pop(context);
                    },
                    child: Icon(
                      Icons.arrow_back_outlined,
                      color: Colors.black54,
                    )),
                title: const Center(
                  child: Image(
                    image: AssetImage("lib/assets/images/logo.png",
                        package: "imepay_merchant_sdk"),
                    width: 80,
                  ),
                ),
                // actions: const [
                //   Padding(
                //     padding: EdgeInsets.only(right: 15.0),
                //     child: Image(
                //       image: AssetImage("lib/assets/images/support.png",
                //           package: "imepay_merchant_sdk"),
                //       height: 24,
                //       width: 24,
                //     ),
                //   )
                // ],
              ),
              body: Container(
                  padding: EdgeInsets.all(15),
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      Text(
                        "Mobile number",
                        style: AppStyle.titleStyleSemibold,
                      ),
                      SizedBox(height: 8),
                      Text(
                        "Enter number registered to IME Pay",
                        style: AppStyle.normalBodyStyle,
                      ),
                      SizedBox(height: 16),
                      Row(
                        children: [
                          Container(
                              width: 120,
                              child: CustomTextInputField(
                                onTap: () {
                                  _openCountryPickerDialog();
                                },
                                controller: _countryCodeControler,
                                readonly: true,
                                icon: Icons.arrow_drop_down_rounded,
                                hint: "Country",
                              )),
                          SizedBox(
                            width: 8,
                          ),
                          Expanded(
                              flex: 3,
                              child: CustomTextInputField(
                                controller: phoneNumberController,
                                maxLenght: textLength,
                                onChanged: (value) {
                                  setState(() {
                                    if (value != null &&
                                        _countryCodeControler.text != "+977" &&
                                        value.length > 7) {
                                      isFloatingActive = true;
                                    } else if (value != null &&
                                        value.length == 10) {
                                      isFloatingActive = true;
                                    } else {
                                      isFloatingActive = false;
                                    }
                                  });
                                },
                                textInputType: TextInputType.number,
                                hint: "Mobile Number",
                              )),
                        ],
                      ),
                    ],
                  ))),
        ));
  }

  void onSubmitClicked() {
    setState(() {
      isLoading = true;
    });
    Webservice().getToken(widget.requestModel).then((response) {
      setState(() {
        isLoading = false;
      });
      if (response != null) {
        String token = response.tokenId.toString();
        var appReponseCode = response.responseCode;

        switch (appReponseCode) {
          case "-1":
            onTokenRecieved(
                ErrorMessage.RESPONSE_FORMAT_ERROR +
                    ErrorMessage.GET_TOKEN_ERROR_CODE,
                ResponseStatus.RESPONSE_STATUS_NEGATIVE);
            break;
          case "1":
            onTokenRecieved(
                ErrorMessage.RESPONSE_EMPTY_TOKEN_ERROR +
                    ErrorMessage.GET_TOKEN_ERROR_CODE,
                ResponseStatus.RESPONSE_STATUS_NEGATIVE);
            break;

          case "0":
            AppConstants.RESPOSNE_TOKEN = token;
            onTokenRecieved(token, ResponseStatus.RESPONSE_STATUS_POSITIVE);
            break;
        }
      } else {
        setState(() {
          isLoading = false;
        });
        final snackBar = SnackBar(
          content: Text(
            "Something went wrong"),
          action: SnackBarAction(
            label: 'OK',
            onPressed: () {
              StartSdk.setResult(
                context,
                PaymentResponseModel(
                    responseDescription:
                    "Transaction cancel by user. RefId= ${widget.requestModel.refId.toString()}",
                    responseCode: -1),
              );
              Navigator.pop(context);
            },
          ),
        );
        _scaffoldKey.currentState!.showSnackBar(snackBar);
        // Get.snackbar("Error", "Something went wrong. Try again.");

        // onTokenRecieved("Something went wrong. Try again.",
        //     ResponseStatus.RESPONSE_STATUS_NEGATIVE);
      }
    });
  }

  void _openCountryPickerDialog() => showDialog(
        context: context,
        builder: (context) => Theme(
          data: Theme.of(context).copyWith(primaryColor: Colors.red),
          child: CountryPickerDialog(
            titlePadding: EdgeInsets.all(8.0),
            searchCursorColor: Colors.pinkAccent,
            searchInputDecoration: InputDecoration(hintText: 'Search...'),
            isSearchable: true,
            title: Text('Select your phone code'),
            onValuePicked: (Country country) {
              setState(() {
                _countryCodeControler.text = "+ " + country.phoneCode;
                if (country.phoneCode == "977") {
                  textLength = 10;
                  countryCode = "";
                } else {
                  textLength = 13;
                  countryCode = "+" + country.phoneCode;
                }
              });
            },
            itemBuilder: _buildDialogItem,
            priorityList: [
              CountryPickerUtils.getCountryByIsoCode('TR'),
              CountryPickerUtils.getCountryByIsoCode('US'),
            ],
          ),
        ),
      );

  Widget _buildDialogItem(Country country) => Column(children: [
        Row(
          children: <Widget>[
            // CountryPickerUtils.getDefaultFlagImage(country),
            SizedBox(width: 8.0),
            Text("+${country.phoneCode}"),
            SizedBox(width: 8.0),
            Flexible(child: Text(country.name))
          ],
        ),
        Divider(color: Colors.grey),
      ]);

  onTokenRecieved(String message, int Status) {
    if (Status == ResponseStatus.RESPONSE_STATUS_POSITIVE) {
      Webservice()
          .postToMerchant(widget.requestModel, message)
          .then((response) async {
        var appResponseCode = response!.responseCode;
        print('Merchant response111 = ${json.encode(response)}');
        String? msg = response.responseDescription;
        switch (appResponseCode) {
          case "-1":
            final snackBar = SnackBar(
              content: Text(ErrorMessage.RESPONSE_FORMAT_ERROR +
                  ErrorMessage.POST_TO_MERCHANT_ERROR_CODE),
              action: SnackBarAction(
                label: 'Cancel',
                onPressed: () {
                  StartSdk.setResult(
                    context,
                    PaymentResponseModel(
                        responseDescription:
                            "Transaction cancel by user. RefId= ${widget.requestModel.refId.toString()}",
                        responseCode: -1),
                  );
                  Navigator.pop(context);
                },
              ),
            );
            _scaffoldKey.currentState!.showSnackBar(snackBar);
            break;

          case "1":
            final snackBar = SnackBar(
              content: Text(
                  msg.toString() + ErrorMessage.POST_TO_MERCHANT_ERROR_CODE),
              action: SnackBarAction(
                label: 'Cancel',
                onPressed: () {
                  StartSdk.setResult(
                    context,
                    PaymentResponseModel(
                        responseDescription:
                            "Transaction cancel by user. RefId= ${widget.requestModel.refId.toString()}",
                        responseCode: -1),
                  );
                  Navigator.pop(context);
                },
              ),
            );
            _scaffoldKey.currentState!.showSnackBar(snackBar);

            break;
          case "0":
            await Navigator.push(
                context,
                MaterialPageRoute(
                  builder: (context) => ReviewScreen(
                      widget.requestModel,
                      countryCode +
                          phoneNumberController.text.toString().trim()),
                ));

            Navigator.pop(context);
            break;
        }
      });
    } else {
      final snackBar = SnackBar(
        content: Text(message),
        action: SnackBarAction(
          label: 'Retry',
          onPressed: () {},
        ),
      );

      ScaffoldMessenger.of(context).showSnackBar(snackBar);
    }

    setState(() {
      isLoading = false;
    });
  }
}
