import 'dart:convert';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import '/constants/app_constants.dart';
import '/model/payment_response_model.dart';
import '/model/request_model.dart';
import '/views/loadin_overlay.dart';
import '/views/success_screen.dart';
import '/webservice/web_service.dart';

import '../start_sdk.dart';

class ErrorScreen extends StatefulWidget {
  RequestModel? requestModel;
  PaymentResponseModel? paymentResponseModel;
  String? msisdn;
  String? walletPin;
  String? tokenId;
  String? message;

  ErrorScreen(this.requestModel, this.msisdn, this.walletPin, this.tokenId,
      this.message);

  @override
  _ErrorScreenState createState() => _ErrorScreenState();
}

class _ErrorScreenState extends State<ErrorScreen> {
  String error = "";
  bool loading = false;
  final GlobalKey<ScaffoldState> _scaffoldKey = new GlobalKey<ScaffoldState>();

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
        onWillPop: () async {
          showDialog(
            context: context,
            builder: (BuildContext context) {
              return AlertDialog(
                content: const Text('Do you really want to abort the payment?'),
                actions: <Widget>[
                  TextButton(
                    onPressed: () {
                      Navigator.pop(context);
                    },
                    child: const Text('No'),
                  ),
                  TextButton(
                    onPressed: () {
                      StartSdk.setResult(
                        context,
                        PaymentResponseModel(
                            responseDescription:
                                "Transaction cancel by user. RefId= ${widget.requestModel!.refId.toString()}",
                            responseCode: -1),
                      );

                      Navigator.pop(context);
                      Navigator.pop(context);
                    },
                    child: const Text('Yes'),
                  ),
                ],
              );
            },
          );

          return true;
        },
        child: LoadingOverlay(
          progressIndicator: CircularProgressIndicator(color: Colors.red,),
          color: Colors.black.withOpacity(0.5),
          isLoading: loading,
          child: Scaffold(
              key: _scaffoldKey,
              backgroundColor: Colors.white,
              appBar: AppBar(
                backgroundColor: Colors.white,
                toolbarHeight: 56,
                title: const Center(
                    child: Padding(
                  padding: EdgeInsets.only(right: 35),
                  child: Image(
                    image: AssetImage("lib/assets/images/logo.png",
                        package: "imepay_merchant_sdk"),
                    width: 80,
                  ),
                )),
                elevation: 0,
                leading: InkWell(
                    onTap: () {
                      showDialog(
                        context: context,
                        builder: (BuildContext context) {
                          return AlertDialog(
                            content: const Text(
                                'Do you really want to abort the payment?'),
                            actions: <Widget>[
                              TextButton(
                                onPressed: () {
                                  Navigator.pop(context,
                                      "Transaction cancel by user. RefId= ${widget.requestModel!.refId.toString()}");
                                },
                                child: const Text('No'),
                              ),
                              TextButton(
                                onPressed: () {
                                  Navigator.pop(context,
                                      "Transaction cancel by user. RefId= ${widget.requestModel!.refId.toString()}");
                                  Navigator.pop(context,
                                      "Transaction cancel by user. RefId= ${widget.requestModel!.refId.toString()}");
                                },
                                child: const Text('Yes'),
                              ),
                            ],
                          );
                        },
                      );
                    },
                    child: Icon(
                      Icons.arrow_back_outlined,
                      color: Colors.black54,
                    )),
              ),
              body: Column(
                children: [
                  Container(
                    height: MediaQuery.of(context).size.height - 250,
                    child: Column(
                      children: [
                        SizedBox(height: 200),
                        Center(
                          child: Icon(
                            Icons.error_outline_sharp,
                            color: Colors.red,
                            size: 35,
                          ),
                        ),
                        Center(
                            child: Text(error,
                                style: TextStyle(
                                  color: Colors.black,
                                  fontSize: 16,
                                  fontFamily: AppFont.Volte_Semibold,
                                  package: "imepay_merchant_sdk",
                                ))),
                        SizedBox(
                          height: 10,
                        ),
                        Center(
                            child: Text("Error",
                                style: TextStyle(
                                  color: Colors.black,
                                  fontSize: 16,
                                  fontFamily: AppFont.Volte_Semibold,
                                  package: "imepay_merchant_sdk",
                                ))),
                        SizedBox(
                          height: 10,
                        ),
                        Center(
                            child: Text(widget.message.toString(),
                                style: AppStyle.normalBodyStyle)),
                      ],
                    ),
                  ),
                  Container(
                      child: Column(
                    children: [
                      InkWell(
                        onTap: () {
                          performPayment(widget.requestModel!.refId.toString(),
                              widget.tokenId.toString());
                        },
                        child: Container(
                          width: 150,
                          height: 40,
                          decoration: BoxDecoration(
                              color: Colors.red.shade400,
                              borderRadius:
                                  BorderRadius.all(Radius.circular(40 / 2))),
                          child: Center(
                              child: Text("Try Again?",
                                  style: TextStyle(
                                    color: Colors.white,
                                    fontSize: 16,
                                    fontFamily: AppFont.Volte,
                                    package: "imepay_merchant_sdk",
                                  ))),
                        ),
                      ),
                      SizedBox(
                        height: 25,
                      ),
                      InkWell(
                          onTap: () {
                            showDialog(
                              context: context,
                              builder: (BuildContext context) {
                                return AlertDialog(
                                  content: const Text(
                                      'Do you really want to abort the payment?'),
                                  actions: <Widget>[
                                    TextButton(
                                      onPressed: () {
                                        Navigator.pop(context);
                                      },
                                      child: const Text('No'),
                                    ),
                                    TextButton(
                                      onPressed: () {
                                        StartSdk.setResult(
                                          context,
                                          PaymentResponseModel(
                                              responseDescription:
                                                  "Transaction cancel by user. RefId= ${widget.requestModel!.refId.toString()}",
                                              responseCode: -1),
                                        );

                                        Navigator.pop(context);
                                        Navigator.pop(context);
                                      },
                                      child: const Text('Yes'),
                                    ),
                                  ],
                                );
                              },
                            );
                          },
                          child: Center(
                              child: Text("Cancel",
                                  style: TextStyle(
                                    color: Colors.black,
                                    fontSize: 16,
                                    fontFamily: AppFont.Volte,
                                    package: "imepay_merchant_sdk",
                                  )))),
                    ],
                  )),
                ],
              )),
        ));
  }

  confirmPayment(PaymentResponseModel paymentResponseModel) {
    Webservice()
        .confirmPayment(widget.requestModel!, widget.msisdn.toString(),
            paymentResponseModel.transactionId.toString())
        .then((response) {
      if (this.mounted) {
        setState(() {
          loading = false;
        });
      }

      if (response != null) {
        if (response.responseCode == 1) {
          final snackBar = SnackBar(
            content: Text(response.responseDescription.toString()),
            action: SnackBarAction(
              label: 'OK',
              onPressed: () {
                _scaffoldKey.currentState!.hideCurrentSnackBar();
              },
            ),
          );
          _scaffoldKey.currentState!.showSnackBar(snackBar);
        } else {
          paymentResponseModel.merchantCode =
              widget.requestModel!.merchantCode.toString();
          paymentResponseModel.refId = widget.requestModel!.refId.toString();
          Navigator.pushReplacement(
              context,
              MaterialPageRoute(
                  builder: (context) => SuccessScreen(
                      widget.requestModel, paymentResponseModel)));
        }
      } else {
        final snackBar = SnackBar(
          content: Text("Something went wrong!"),
          action: SnackBarAction(
            label: 'Ok',
            onPressed: () {
              _scaffoldKey.currentState!.hideCurrentSnackBar();
            },
          ),
        );
        _scaffoldKey.currentState!.showSnackBar(snackBar);
      }
    });
  }

  performPayment(String refId, String tokenId) {
    Webservice()
        .performTransaction(widget.requestModel!, widget.msisdn.toString(),
            widget.walletPin.toString(), AppConstants.RESPOSNE_TOKEN)
        .then((response) {
      print('payment response = ${json.encode(response)}');
      if (response != null) {
        if (response.responseCode == -1) {
          if (this.mounted) {
            setState(() {
              loading = false;
            });
          }

          final snackBar = SnackBar(
            content: Text(ErrorMessage.RESPONSE_FORMAT_ERROR),
            action: SnackBarAction(
              label: 'OK',
              onPressed: () {
                _scaffoldKey.currentState!.hideCurrentSnackBar();
              },
            ),
          );
          _scaffoldKey.currentState!.showSnackBar(snackBar);
        } else if (response.responseCode == 1) {
          if (this.mounted) {
            setState(() {
              loading = false;
            });
          }

          final snackBar = SnackBar(
            content: Text(response.responseDescription.toString()),
            action: SnackBarAction(
              label: 'OK',
              onPressed: () {
                _scaffoldKey.currentState!.hideCurrentSnackBar();
              },
            ),
          );
          _scaffoldKey.currentState!.showSnackBar(snackBar);
        } else {
          confirmPayment(response);
        }
      } else {
        if (this.mounted) {
          setState(() {
            loading = false;
          });
        }

        final snackBar = SnackBar(
          duration: Duration(milliseconds: 500000),
          content: Text("Something went wrong!"),
          action: SnackBarAction(
            label: 'Ok',
            onPressed: () {
              _scaffoldKey.currentState!.hideCurrentSnackBar();
            },
          ),
        );
        _scaffoldKey.currentState!.showSnackBar(snackBar);
      }
    });
  }
}
