import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import '/constants/app_constants.dart';
import '/model/payment_response_model.dart';
import '/views/verify_screen.dart';
import '/model/request_model.dart';
import '/webservice/web_service.dart';
import '/utils/utils.dart';
import '../start_sdk.dart';
import 'loadin_overlay.dart';

class PinScreen extends StatefulWidget {
  String msisdn;
  RequestModel requestModel;

  PinScreen(this.requestModel, this.msisdn);

  @override
  _PinScreenState createState() => _PinScreenState();
}

class _PinScreenState extends State<PinScreen> {
  final GlobalKey<ScaffoldState> _scaffoldKey = new GlobalKey<ScaffoldState>();
  String name = "";
  String pin = "";
  bool isLoading = false;
  List<String> gridViewList = [
    "1",
    "2",
    "3",
    "4",
    "5",
    "6",
    "7",
    "8",
    "9",
    "CANCEL",
    "0",
    "-1"
  ];

  @override
  initState() {
    name = widget.requestModel.merchantName.toString();
  }

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
        onWillPop: () async {
          showDialog(
            context: context,
            builder: (BuildContext context) {
              return AlertDialog(
                content: const Text('Do you really want to abort the payment?'),
                actions: <Widget>[
                  TextButton(
                    onPressed: () {
                      Navigator.pop(context);
                    },
                    child: const Text('No'),
                  ),
                  TextButton(
                    onPressed: () {
                      StartSdk.setResult(
                        context,
                        PaymentResponseModel(
                            responseDescription:
                                "Transaction cancel by user. RefId= ${widget.requestModel.refId.toString()}",
                            responseCode: -1),
                      );
                      Navigator.pop(context);
                      Navigator.pop(context);
                    },
                    child: const Text('Yes'),
                  ),
                ],
              );
            },
          );
          return false;
        },
        child: LoadingOverlay(
            isLoading: isLoading,
            progressIndicator: CircularProgressIndicator(color: Colors.red,),
            color: Colors.black.withOpacity(0.5),
            child: Scaffold(
                key: _scaffoldKey,
                backgroundColor: Colors.white,
                body: SafeArea(
                    child: SingleChildScrollView(
                        child: Container(
                  height: MediaQuery.of(context).size.height,
                  child: Column(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      _reviewBodyWidget(),
                      Column(children: [
                        _keyPadLayout(),
                        Container(
                          height: 50,
                          child: Text(
                            "Version 3.0.4(139)",
                            style: AppStyle.normalBodyStyle,
                          ),
                        )
                      ]),
                    ],
                  ),
                ))))));
  }

  _reviewBodyWidget() {
    return Container(
      child: Column(
        children: [
          SizedBox(height: Utils.getSizeInt(context, 80)),
          Center(
              child: Container(
                padding: EdgeInsets.all(8),
                decoration: BoxDecoration(
                    shape: BoxShape.circle,
                    color: Colors.grey.shade100
                ),
                child: ClipRRect(
                    borderRadius: BorderRadius.circular(32),
                    child: Image.asset(widget.requestModel.logo.toString(), height: 64,width: 64, fit: BoxFit.contain,)
                ),
              ),
          ),
          SizedBox(
            height: Utils.getSizeInt(context, 20),
          ),
          Text(
            "Good ${greeting()}, $name",
            style: AppStyle.titleStyle,
          ),
          SizedBox(
            height: Utils.getSizeInt(context, 8),
          ),
          Text(
            "Verify your transaction",
            style: AppStyle.normalBodyStyle,
          ),
          SizedBox(
            height: Utils.getSizeInt(context, 32),
          ),
          Row(
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              Container(
                height: 16,
                width: 16,
                decoration: BoxDecoration(
                    color: pin.length > 0
                        ? Colors.lightBlueAccent
                        : Colors.transparent,
                    shape: BoxShape.circle,
                    border:
                        Border.all(color: Colors.lightBlueAccent, width: 2)),
              ),
              Container(
                margin: EdgeInsets.only(left: 16),
                height: 16,
                width: 16,
                decoration: BoxDecoration(
                    color: pin.length > 1
                        ? Colors.lightBlueAccent
                        : Colors.transparent,
                    shape: BoxShape.circle,
                    border:
                        Border.all(color: Colors.lightBlueAccent, width: 2)),
              ),
              Container(
                margin: EdgeInsets.only(left: 16),
                height: 16,
                width: 16,
                decoration: BoxDecoration(
                    color: pin.length > 2
                        ? Colors.lightBlueAccent
                        : Colors.transparent,
                    shape: BoxShape.circle,
                    border:
                        Border.all(color: Colors.lightBlueAccent, width: 2)),
              ),
              Container(
                margin: EdgeInsets.only(left: 16),
                height: 16,
                width: 16,
                decoration: BoxDecoration(
                    color: pin.length > 3
                        ? Colors.lightBlueAccent
                        : Colors.transparent,
                    shape: BoxShape.circle,
                    border:
                        Border.all(color: Colors.lightBlueAccent, width: 2)),
              ),
            ],
          ),
        ],
      ),
    );
  }

  _keyPadLayout() {
    return GridView.count(
      shrinkWrap: true,
      padding: EdgeInsets.all(Utils.getSizeInt(context, 16)),
      crossAxisCount: 3,
      childAspectRatio:
          (Utils.getSizeInt(context, 80) / Utils.getSizeInt(context, 50)),
      children: gridViewList.map((value) {
        return InkWell(
          onTap: () {
            if (value == "CANCEL") {
              showDialog(
                context: context,
                builder: (BuildContext context) {
                  return AlertDialog(
                    content:
                        const Text('Do you really want to abort the payment?'),
                    actions: <Widget>[
                      TextButton(
                        onPressed: () {
                          Navigator.pop(context);
                        },
                        child: const Text('No'),
                      ),
                      TextButton(
                        onPressed: () {
                          StartSdk.setResult(
                            context,
                            PaymentResponseModel(
                                responseDescription:
                                    "Transaction cancel by user. RefId= ${widget.requestModel.refId.toString()}",
                                responseCode: -1),
                          );
                          Navigator.pop(context);
                          Navigator.pop(context);
                        },
                        child: const Text('Yes'),
                      ),
                    ],
                  );
                },
              );
            } else if (value == "-1") {
              String selectedPin = "";
              if (pin != null && pin.length > 0) {
                setState(() {
                  pin = pin.substring(0, pin.length - 1);
                });
              }
            } else {
              setState(() {
                if (pin.length < 4) pin = pin + value;
                if (pin.length == 4) {
                  setState(() {
                    isLoading = true;
                  });
                  Webservice()
                      .requestForOTP(widget.requestModel, widget.msisdn, pin)
                      .then((response) async {
                    setState(() {
                      isLoading = false;
                    });

                    if (response != null) {

                      switch (response.responseCode) {
                        case -1:
                          setState(() {
                            pin = "";
                          });
                          showDialog(
                            context: context,
                            builder: (BuildContext context) {
                              return AlertDialog(
                                title: Text(
                                  "Error",
                                  style: AppStyle.titleStyle,
                                ),
                                content: Text(
                                  response.responseDescription.toString(),
                                  style: AppStyle.normalBodyStyle,
                                ),
                                actions: [
                                  TextButton(
                                      onPressed: () {
                                        StartSdk.setResult(context,
                                            "Transaction cancel by user. RefId= ${widget.requestModel.refId.toString()}");
                                        Navigator.pop(context);
                                      },
                                      child: Text(
                                        "Cancel",
                                        style: AppStyle.insideTextFieldStyle,
                                      ))
                                ],
                              );
                            },
                          );
                          break;

                        case 100:
                          var newPin = pin;
                          await Navigator.push(
                              context,
                              MaterialPageRoute(
                                  builder: (context) => VerifyScreen(
                                      widget.requestModel,
                                      widget.msisdn,
                                      newPin)));

                          Navigator.pop(context);

                          setState(() {
                            pin = "";
                          });

                          break;

                        case 101:
                          setState(() {
                            pin = "";
                          });
                          showDialog(
                            context: context,
                            builder: (BuildContext context) {
                              return AlertDialog(
                                title: Text(
                                  "Error",
                                  style: AppStyle.titleStyle,
                                ),
                                content: Text(
                                  response.responseDescription.toString(),
                                  style: AppStyle.normalBodyStyle,
                                ),
                                actions: [
                                  TextButton(
                                      onPressed: () {
                                        StartSdk.setResult(context,
                                            "Transaction cancel by user. RefId= ${widget.requestModel.refId.toString()}");
                                        Navigator.pop(context);
                                        Navigator.pop(context);
                                      },
                                      child: Text(
                                        "Cancel",
                                        style: AppStyle.insideTextFieldStyle,
                                      ))
                                ],
                              );
                            },
                          );
                          break;

                        case 102:
                          setState(() {
                            pin = "";
                          });

                          final snackBar = SnackBar(
                            content:
                                Text(response.responseDescription.toString()),
                            action: SnackBarAction(
                              label: '',
                              onPressed: () {
                                // Navigator.pop(context);
                              },
                            ),
                          );
                          _scaffoldKey.currentState!.showSnackBar(snackBar);

                          break;

                        case 115:
                          setState(() {
                            pin = "";
                          });
                          showDialog(
                            context: context,
                            builder: (BuildContext context) {
                              return AlertDialog(
                                title: Text(
                                  "Error",
                                  style: AppStyle.titleStyle,
                                ),
                                content: Text(
                                  response.responseDescription.toString(),
                                  style: AppStyle.normalBodyStyle,
                                ),
                                actions: [
                                  TextButton(
                                      onPressed: () {
                                        StartSdk.setResult(context,
                                            "Transaction cancel by user. RefId= ${widget.requestModel.refId.toString()}");
                                        Navigator.pop(context);
                                        Navigator.pop(context);
                                      },
                                      child: Text(
                                        "Cancel",
                                        style: AppStyle.insideTextFieldStyle,
                                      ))
                                ],
                              );
                            },
                          );
                          break;

                      }
                    } else {
                      showDialog(
                        context: context,
                        builder: (BuildContext context) {
                          return AlertDialog(
                            title: Text(
                              "Error",
                              style: AppStyle.titleStyle,
                            ),
                            content: Text(
                              "Something went wrong".toString(),
                              style: AppStyle.normalBodyStyle,
                            ),
                            actions: [
                              TextButton(
                                  onPressed: () {
                                    StartSdk.setResult(context,
                                        "Transaction cancel by user. RefId= ${widget.requestModel.refId.toString()}");
                                    Navigator.pop(context);
                                  },
                                  child: Text(
                                    "Cancel",
                                    style: AppStyle.insideTextFieldStyle,
                                  ))
                            ],
                          );
                        },
                      );
                    }
                  });
                }
              });
            }
          },
          child: Container(
            alignment: Alignment.center,
            margin: EdgeInsets.all(1),
            child: value == "-1"
                ? Image(
                    image: AssetImage("lib/assets/images/backspace.png",
                        package: "imepay_merchant_sdk"),
                    width: 24,
                  )
                : Text(
                    value,
                    style: value == "CANCEL"
                        ? TextStyle(
                            color: Colors.black,
                            fontSize: 14,
                            package: "imepay_merchant_sdk",
                            fontFamily: AppFont.Volte_Semibold)
                        : AppStyle.titleStyleSemibold,
                  ),
          ),
        );
      }).toList(),
    );
  }


  String greeting() {
    var hour = DateTime.now().hour;
    if (hour < 12) {
      return 'Morning';
    }
    if (hour < 17) {
      return 'Afternoon';
    }
    return 'Evening';
  }
}
