import 'dart:convert';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import '/constants/app_constants.dart';
import '/model/payment_response_model.dart';
import '/model/request_model.dart';
import '/views/pin_layout.dart';
import '../start_sdk.dart';

class ReviewScreen extends StatefulWidget {
  RequestModel requestModel;
  String msisdn;

  ReviewScreen(this.requestModel, this.msisdn);

  @override
  _ReviewScreenState createState() => _ReviewScreenState();
}

class _ReviewScreenState extends State<ReviewScreen> {
  String merchantName = "";
  String customerName = "";
  String phoneNumber = "";
  String payAmount = "";

  @override
  void initState() {
    super.initState();
    merchantName = widget.requestModel.merchantName.toString();
    customerName = widget.requestModel.customerName.toString();
    phoneNumber = widget.msisdn.toString();
    payAmount = widget.requestModel.amount.toString().split(".")[0];
  
  }

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
        onWillPop: () async {
          showDialog(
            context: context,
            builder: (BuildContext context) {
              return AlertDialog(
                content: const Text('Do you really want to abort the payment?'),
                actions: <Widget>[
                  TextButton(
                    onPressed: () {
                      Navigator.pop(context);
                    },
                    child: const Text('No'),
                  ),
                  TextButton(
                    onPressed: () {
                      StartSdk.setResult(
                        context,
                        PaymentResponseModel(
                            responseDescription:
                            "Transaction cancel by user. RefId= ${widget
                                .requestModel.refId.toString()}",
                            responseCode: -1),
                      );
                      Navigator.pop(context);
                      Navigator.pop(context);
                    },
                    child: const Text('Yes'),
                  ),
                ],
              );
            },
          );
          return false;
        },
        child: Scaffold(
            backgroundColor: Colors.white,
            appBar: AppBar(
              backgroundColor: Colors.white,
              toolbarHeight: 56,
              elevation: 0,
              leading: InkWell(
                  onTap: () {
                    showDialog(
                      context: context,
                      builder: (BuildContext context) {
                        return AlertDialog(
                          content: const Text(
                              'Do you really want to abort the payment?'),
                          actions: <Widget>[
                            TextButton(
                              onPressed: () {
                                Navigator.pop(context,
                                    "Transaction cancel by user. RefId= ${widget
                                        .requestModel.refId}");
                              },
                              child: const Text('No'),
                            ),
                            TextButton(
                              onPressed: () {
                                Navigator.pop(context,
                                    "Transaction cancel by user. RefId= ${widget
                                        .requestModel.refId.toString()}");
                                Navigator.pop(context,
                                    "Transaction cancel by user. RefId= ${widget
                                        .requestModel.refId.toString()}");
                              },
                              child: const Text('Yes'),
                            ),
                          ],
                        );
                      },
                    );
                  },
                  child: Icon(
                    Icons.arrow_back_outlined,
                    color: Colors.black54,
                  )),
              title: Padding(
                  padding: EdgeInsets.only(right: 25),
                  child: Center(
                      child: Text("Review Transaction",
                          style: AppStyle.titleStyle))),
            ),
            body: _reviewBodyWidget()));
  }

  Widget _reviewBodyWidget() {
    return Stack(children: [
      Column(
        children: [
          Container(
              margin: EdgeInsets.all(16),
              child: Row(
                children: [
                  Container(
                    padding: EdgeInsets.all(8),
                    decoration: BoxDecoration(
                      shape: BoxShape.circle,
                      color: Colors.grey.shade100
                    ),
                    child: ClipRRect(
                      borderRadius: BorderRadius.circular(15),
                      child: Image.asset(widget.requestModel.logo.toString(), height: 45,width: 45, fit: BoxFit.contain,)
                    ),
                  ),

                  SizedBox(
                    width: 5,
                  ),
                  Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      Text(
                        merchantName,
                        style: AppStyle.titleStyle,
                      ),
                      SizedBox(
                        height: 4,
                      ),
                      Row(
                        children: [
                          Text(
                            "Wallet no",
                            style: AppStyle.normalBodyStyle,
                          ),
                          Container(
                              margin: EdgeInsets.only(left: 4, right: 4),
                              width: 6,
                              height: 6,
                              decoration: const BoxDecoration(
                                shape: BoxShape.circle,
                                color: Colors.lightBlueAccent,
                              )),
                          Text(
                            phoneNumber,
                            style: AppStyle.normalBodyStyle,
                          ),
                        ],
                      ),
                    ],
                  )
                ],
              )),
          Container(
              padding: EdgeInsets.all(16),
              width: MediaQuery
                  .of(context)
                  .size
                  .width,
              color: Colors.grey.shade100,
              child: const Text(
                "Payment Details",
                style: AppStyle.secondaryTitleStyle,
              )),
          Container(
              margin: EdgeInsets.all(8),
              decoration: BoxDecoration(
                borderRadius: BorderRadius.all(Radius.circular(4)),
                border: Border.all(
                  color: Colors.grey.shade300,
                ),
              ),
              child: Column(children: [
                Container(
                    padding: const EdgeInsets.only(
                        left: 8, right: 8, top: 20, bottom: 20),
                    child: Row(
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: [
                        Text(
                          "Transaction Amount",
                          style: AppStyle.listItemStyle,
                        ),
                        Text(
                          "Rs. $payAmount",
                          style: AppStyle.listItemStyle,
                        ),
                      ],
                    )),
                Container(
                  margin: EdgeInsets.symmetric(horizontal: 8),
                  height: 1,
                  color: Colors.grey.shade300,
                ),
                Container(
                    padding: const EdgeInsets.only(
                        left: 8, right: 8, top: 20, bottom: 20),
                    child: Row(
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: [
                        Text(
                          "Total Paying",
                          style: AppStyle.footerListStyle,
                        ),
                        Text(
                          "Rs. $payAmount",
                          style: AppStyle.footerListStyle,
                        ),
                      ],
                    ))
              ])),
          Visibility(
              visible: false,
              child: Container(
                  margin: EdgeInsets.only(top: 8),
                  padding: EdgeInsets.all(16),
                  width: MediaQuery
                      .of(context)
                      .size
                      .width,
                  color: Colors.grey.shade100,
                  child: Text(
                    "Payment Details",
                    style: AppStyle.secondaryTitleStyle,
                  ))),
          Visibility(
              visible: false,
              child: Container(
                  margin: EdgeInsets.all(8),
                  decoration: BoxDecoration(
                    borderRadius: BorderRadius.all(Radius.circular(4)),
                    border: Border.all(
                      color: Colors.grey.shade300,
                    ),
                  ),
                  child: Column(children: [
                    Container(
                        padding: const EdgeInsets.only(
                            left: 8, right: 8, top: 20, bottom: 20),
                        child: Row(
                          mainAxisAlignment: MainAxisAlignment.spaceBetween,
                          children: [
                            Row(
                              children: [
                                Text(
                                  "Platinum Member",
                                  style: AppStyle.listItemStyle,
                                ),
                                SizedBox(
                                  width: 2,
                                ),
                                Icon(
                                  Icons.stars,
                                  color: Colors.indigo,
                                  size: 15,
                                )
                                //  Image(
                                //   image: AssetImage("lib/assets/images/support.png",
                                //       package: "imepay_merchant_sdk"),
                                //   width: 40,
                                //   height: 40,
                                // ),
                              ],
                            ),
                            Text(
                              "1.5x",
                              style: AppStyle.listItemStyle,
                            ),
                          ],
                        )),
                    Container(
                      margin: EdgeInsets.symmetric(horizontal: 8),
                      height: 1,
                      color: Colors.grey.shade300,
                    ),
                    Container(
                        padding: const EdgeInsets.only(
                            left: 8, right: 8, top: 20, bottom: 20),
                        child: Row(
                          mainAxisAlignment: MainAxisAlignment.spaceBetween,
                          children: [
                            Text(
                              "Total reward points",
                              style: AppStyle.footerListStyle,
                            ),
                            Text(
                              "Rs.150 pts",
                              style: AppStyle.footerListStyle,
                            ),
                          ],
                        ))
                  ]))),
        ],
      ),
      Align(
          alignment: Alignment.bottomCenter,
          child: InkWell(
              onTap: () async {
                await Navigator.push(
                    context,
                    MaterialPageRoute(
                        builder: (context) =>
                            PinScreen(widget.requestModel, widget.msisdn)));
                Navigator.pop(context);
              },
              child: Container(
                  width: MediaQuery
                      .of(context)
                      .size
                      .width,
                  margin: EdgeInsets.only(left: 16, right: 16, bottom: 20),
                  height: 48,
                  decoration: BoxDecoration(
                    color: Colors.red.shade800,
                    borderRadius: BorderRadius.circular(48 / 2),
                  ),
                  child: Center(
                      child: Text("Pay Rs. $payAmount",
                          style: TextStyle(
                              color: Colors.white,
                              fontSize: 14,
                              package: "imepay_merchant_sdk",
                              fontFamily: AppFont.Volte,
                              fontWeight: FontWeight.w700))))))
    ]);
  }
}
