import 'dart:convert';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import '/constants/app_constants.dart';
import '/model/payment_response_model.dart';
import '/model/request_model.dart';

import '../start_sdk.dart';

class SuccessScreen extends StatefulWidget {
  RequestModel? requestModel;
  PaymentResponseModel? paymentResponseModel;

  SuccessScreen(this.requestModel, this.paymentResponseModel);

  @override
  _SuccessScreenState createState() => _SuccessScreenState();
}

class _SuccessScreenState extends State<SuccessScreen> {
  String amount = "";
  String merchantName = "";

  @override
  void initState() {
    setState(() {
      amount = widget.requestModel!.amount.toString().split(".")[0];
      merchantName = widget.requestModel!.merchantName.toString();
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
        onWillPop: () async {
          StartSdk.setResult(context, widget.paymentResponseModel!);
          Navigator.pop(context);
          return true;
        },
        child: Scaffold(
            backgroundColor: Colors.white,
            appBar: AppBar(
              backgroundColor: Colors.white,
              toolbarHeight: 56,
              elevation: 0,
            ),
            body: Column(
              children: [
                Align(
                    alignment: Alignment.topCenter,
                    child: SizedBox(
                      height: 100,
                    )),
                Expanded(
                    child: Column(
                  children: [
                    Container(
                      height: 100,
                      child: Stack(
                        children: [
                          Center(
                            child:
                            Container(
                              padding: EdgeInsets.all(8),
                              decoration: BoxDecoration(
                                  shape: BoxShape.circle,
                                  color: Colors.grey.shade100
                              ),
                              child: ClipRRect(
                                  borderRadius: BorderRadius.circular(32),
                                  child: Image.asset(widget.requestModel!.logo.toString(), height: 64,width: 64, fit: BoxFit.contain,)
                              ),
                            ),

                            /*CircleAvatar(
                              radius: 40,
                              backgroundImage: AssetImage(
                                  "lib/assets/images/logo.png",
                                  package: "imepay_merchant_sdk"),
                            ),*/
                          ),
                          Positioned(
                            child: Align(
                              alignment: FractionalOffset.bottomCenter,
                              child: Container(
                                height: 24,
                                decoration: BoxDecoration(
                                    shape: BoxShape.circle,
                                    color: Colors.lightBlueAccent.shade100),
                                child: Image(
                                  image: AssetImage(
                                      "lib/assets/images/double_tick.png",
                                      package: "imepay_merchant_sdk"),
                                  width: 12,
                                  height: 12,
                                ),
                              ),
                            ),
                          ),
                        ],
                      ),
                    ),
                    const SizedBox(
                      height: 52,
                    ),
                    RichText(
                      text: TextSpan(
                        text: 'Rs. ',
                        style: AppStyle.titleStyleMedium,
                        children: <TextSpan>[
                          TextSpan(
                              text: amount,
                              style: const TextStyle(
                                color: Colors.black87,
                                fontSize: 60,
                                fontFamily: AppFont.Volte_Medium,
                                package: "imepay_merchant_sdk",
                              )),
                        ],
                      ),
                    ),
                    SizedBox(height: 32),
                    Text(
                      "Paid for $merchantName successfully",
                      style: AppStyle.normalBodyStyle,
                    )
                  ],
                )),
                InkWell(
                    onTap: () {
                      StartSdk.setResult(
                          context, json.encode(widget.paymentResponseModel));
                      Navigator.pop(context);
                    },
                    child: Container(
                      margin: EdgeInsets.only(bottom: 24),
                      height: 48,
                      width: 160,
                      decoration: BoxDecoration(
                          borderRadius:
                              BorderRadius.all(Radius.circular(48 / 2)),
                          border: Border.all(color: Colors.black54, width: 2)),
                      child: const Center(
                          child: Text(
                        "DONE",
                        style: TextStyle(
                          color: Colors.black54,
                          fontSize: 14,
                          fontFamily: AppFont.Volte_Semibold,
                          package: "imepay_merchant_sdk",
                        ),
                      )),
                    ))
              ],
            )));
  }
}
