import 'dart:convert';
import 'package:get/get.dart';
import '/constants/app_constants.dart';
import '/model/merchant_response_model.dart';
import '/model/mobile_verify_model.dart';
import '/model/payment_response_model.dart';
import '/model/request_model.dart';
import '/model/tokern_response.dart';

class Webservice extends GetConnect {
  Future<TokenResponseModel?> getToken(RequestModel requestModel) async {
    try {
      String authToken =
          "Basic ${base64.encode(utf8.encode(
          "${requestModel.user.toString()}:${requestModel.password
              .toString()}"))}";
      String url = ApiConstants.getSelectedBaseUrl() + ApiConstants.GET_TOKEN;

      Map<String, String> data = new Map();
      data["MerchantCode"] = requestModel.merchantCode.toString();
      data["Amount"] = requestModel.amount.toString();
      data["RefId"] = requestModel.refId.toString();
      data["DeliveryUrl"] = requestModel.deliveryUrl.toString();

      Map<String, String> headers = new Map();
      headers["Authorization"] = authToken;
      headers["Module"] = requestModel.module.toString();
      headers["Content-Type"] = "application/json;charset=UTF-8";

      var response = await super.post(url, json.encode(data),
          contentType: "application/json", headers: headers);
      print("Token  request data = ${json.encode(
          data)} has error = ${response.hasError}");

      if (response.body == null) {
        Get.snackbar("Error", response.body["Message"]);
        return null;
      } else if (response.hasError) {
        Get.snackbar("Error", response.body["Message"]);
        return null;
      } else {
        TokenResponseModel model = TokenResponseModel.fromJson(response.body);
        return model;
      }
    } catch (ex) {
      print("error: ${ex.toString()}");
      return null;
    }
  }

  Future<MerchantResponseModel?> postToMerchant(RequestModel requestModel,
      String tokenId) async {
    try {
      String authToken =
          "Basic ${base64.encode(utf8.encode(
          "${requestModel.user.toString()}:${requestModel.password
              .toString()}"))}";

      //Setup post data
      Map<String, String> data = new Map();
      data["TokenId"] = tokenId.toString();
      data["Amount"] = requestModel.amount.toString();
      data["ReferenceId"] = requestModel.refId.toString();
      data["MerchantCode"] = requestModel.merchantCode.toString();

      //Setup headers data
      Map<String, String> headers = new Map();
      headers["Authorization"] = authToken;
      headers["Module"] = requestModel.module.toString();
      headers["Content-Type"] = "application/json;charset=UTF-8";

      var response = await super.post(
          requestModel.merchantUrl, json.encode(data),
          contentType: "application/json", headers: headers);
      print("Merchant Respoddnses = ${json.encode(
          response.body)} has error = ${response.hasError}");

      if (response.hasError) {
        Get.snackbar("Error", response.body["Message"]);
        return null;
      } else {
        MerchantResponseModel model = MerchantResponseModel.fromJson(
            response.body);
        return model;
      }
    } catch (ex) {
      print("error : ${ex.toString()}");
    }
  }

  Future<MobileVerifyModel?> requestForOTP(RequestModel requestModel,
      String msisdn, pin) async {
    try {
      String authToken =
          "Basic ${base64.encode(utf8.encode(
          "${requestModel.user.toString()}:${requestModel.password
              .toString()}"))}";
      String url = ApiConstants.getSelectedBaseUrl() + ApiConstants.VALIDATE_USER;
      Map<String, String> data = new Map();
      data["Msisdn"] = msisdn;
      data["Pin"] = pin;
      data["MerchantCode"] = requestModel.merchantCode.toString();

      Map<String, String> headers = new Map();
      headers["Authorization"] = authToken;
      headers["Module"] = requestModel.module.toString();
      headers["Content-Type"] = "application/json;charset=UTF-8";

      var response = await super.post(url, json.encode(data),
          contentType: "application/json", headers: headers);
      print("request otp response= ${json.encode(response.body)}");

      if (response.hasError) {
        Get.snackbar("Error", response.body["Message"]);
        return null;
      } else {
        MobileVerifyModel model = MobileVerifyModel.fromJson(response.body);
        return model;
      }
    } catch (ex) {
      print("error: ${ex.toString()}");
      return null;
    }
  }


  Future<MobileVerifyModel?> validateOtp(RequestModel requestModel,
      String msisdn, String otp) async {
    try {
      String authToken =
          "Basic ${base64.encode(utf8.encode(
          "${requestModel.user.toString()}:${requestModel.password
              .toString()}"))}";
      String url =ApiConstants.getSelectedBaseUrl() + ApiConstants.VALIDATE_OTP;
      Map<String, String> data = new Map();
      data["Otp"] = otp;
      data["Msisdn"] = msisdn;
      data["MerchantCode"] = requestModel.merchantCode.toString();

      Map<String, String> headers = new Map();
      headers["Authorization"] = authToken;
      headers["Module"] = requestModel.module.toString();
      headers["Content-Type"] = "application/json;charset=UTF-8";

      var response = await super.post(url, json.encode(data),
          contentType: "application/json", headers: headers);

      if (response.hasError) {
        Get.snackbar("Error", response.body["Message"]);
        return null;
      } else {
        MobileVerifyModel model = MobileVerifyModel.fromJson(response.body);
        return model;
      }
    } catch (ex) {
      print("error: ${ex.toString()}");
      return null;
    }
  }

  Future<PaymentResponseModel?> confirmPayment(RequestModel requestModel,
      String msisdn, String transactionId) async {
    try {
      String authToken =
          "Basic ${base64.encode(utf8.encode(
          "${requestModel.user.toString()}:${requestModel.password
              .toString()}"))}";
      String url =ApiConstants.getSelectedBaseUrl() + ApiConstants.CONFIRM_PAYMENT;

      Map<String, String> data = new Map();
      data["RefId"] = requestModel.refId.toString();
      data["TransactionId"] = transactionId;
      data["MerchantCode"] = requestModel.merchantCode.toString();
      data["Msisdn"] = msisdn;

      Map<String, String> headers = new Map();
      headers["Authorization"] = authToken;
      headers["Module"] = requestModel.module.toString();
      headers["Content-Type"] = "application/json;charset=UTF-8";

      var response = await super.post(url, json.encode(data),
          contentType: "application/json", headers: headers);

      if (response.hasError) {
        Get.snackbar("Error", response.body["Message"]);
        return null;
      } else {
        PaymentResponseModel model = PaymentResponseModel.fromJson(
            response.body);
        return model;
      }
    } catch (ex) {
      print("error: ${ex.toString()}");
      return null;
    }
  }


  Future<PaymentResponseModel?> performTransaction(RequestModel requestModel,
      String msisdn, String pin, String tokenId) async {
    try {
      String authToken =
          "Basic ${base64.encode(utf8.encode(
          "${requestModel.user.toString()}:${requestModel.password
              .toString()}"))}";
      String url = ApiConstants.getSelectedBaseUrl() + ApiConstants.PAYMENT;


      Map<String, String> data = new Map();
      data["RefId"] = requestModel.refId.toString();
      data["Amount"] = requestModel.amount.toString();
      data["MerchantCode"] = requestModel.merchantCode.toString();
      data["Msisdn"] = msisdn;
      data["pin"] = pin;
      data["TokenId"] = tokenId;

      Map<String, String> headers = new Map();
      headers["Authorization"] = authToken;
      headers["Module"] = requestModel.module.toString();
      headers["Content-Type"] = "application/json;charset=UTF-8";

      var response = await super.post(url, json.encode(data),
          contentType: "application/json", headers: headers);

      if (response.hasError) {
        Get.snackbar("Error", response.body["Message"].toString());
        return null;
      } else {
        PaymentResponseModel model = PaymentResponseModel.fromJson(
            response.body);
        return model;
      }
    }catch(ex){
      print("error : ${ex.toString()}");
    }
  }
}
